==> antd-mobile-2.1.3.tgz: package/es/steps/demo/basic.native.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
/* tslint:disable:jsx-no-multiline-js */
import { WingBlank, Icon } from 'antd-mobile';
import Steps from '../index.native';
var Step = Steps.Step;
import React from 'react';
import { View, ScrollView, Text } from 'react-native';

var BasicTimelineExample = function (_React$Component) {
  _inherits(BasicTimelineExample, _React$Component);

  function BasicTimelineExample(props) {
    _classCallCheck(this, BasicTimelineExample);

    var _this = _possibleConstructorReturn(this, (BasicTimelineExample.__proto__ || Object.getPrototypeOf(BasicTimelineExample)).call(this, props));

    _this.state = {
      steps1: [{ title: 'Finished', description: 'This is description' }, { title: 'In Progress', description: 'This is description' }, { title: 'Waiting', description: 'This is description' }],
      steps2: [{ title: 'Finished', description: 'This is description', status: 'finish' }, { title: 'In Progress', description: 'This is description', status: 'process' }, { title: 'Waiting', description: 'This is description', status: 'error' }, { title: 'Waiting', description: 'This is description', status: 'wait' }]
    };
    return _this;
  }

  _createClass(BasicTimelineExample, [{
    key: 'render',
    value: function render() {
      return React.createElement(
        ScrollView,
        { style: { flex: 1 }, automaticallyAdjustContentInsets: false, showsHorizontalScrollIndicator: false, showsVerticalScrollIndicator: false },
        React.createElement(
          View,
          { style: { marginTop: 60 } },
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              { size: 'small', current: 1, direction: 'horizontal' },
              this.state.steps1.map(function (item, index) {
                return React.createElement(Step, { key: index, title: React.createElement(
                    View,
                    null,
                    React.createElement(
                      Text,
                      null,
                      'title:',
                      item.title
                    )
                  ), status: item.status });
              })
            )
          )
        ),
        React.createElement(
          View,
          { style: { marginTop: 60 } },
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              { size: 'small', current: 1 },
              this.state.steps1.map(function (item, index) {
                return React.createElement(Step, { key: index, title: React.createElement(
                    View,
                    null,
                    React.createElement(
                      Text,
                      null,
                      'title:',
                      item.title
                    )
                  ), description: React.createElement(
                    View,
                    null,
                    React.createElement(
                      Text,
                      null,
                      'desc:',
                      item.description
                    )
                  ), status: item.status });
              })
            )
          )
        ),
        React.createElement(
          View,
          null,
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              { size: 'small' },
              this.state.steps2.map(function (item, index) {
                return React.createElement(Step, { key: index, title: item.title, description: item.description, status: item.status });
              })
            )
          )
        ),
        React.createElement(
          View,
          null,
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              { current: 1 },
              this.state.steps1.map(function (item, index) {
                return React.createElement(Step, { key: index, title: item.title, description: item.description, status: item.status });
              })
            )
          )
        ),
        React.createElement(
          View,
          null,
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              null,
              this.state.steps2.map(function (item, index) {
                return React.createElement(Step, { key: index, title: item.title, description: item.description, status: item.status });
              })
            )
          )
        ),
        React.createElement(
          View,
          null,
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              { current: 1 },
              React.createElement(Step, { key: 0, title: 'Finished', description: 'This is description', status: 'finish' }),
              React.createElement(Step, { key: 1, title: 'Progress', description: 'This is description', status: 'progress' }),
              React.createElement(Step, { key: 2, title: 'Wait', description: 'This is description', status: 'wait', icon: React.createElement(Icon, { type: 'down', size: 20, color: 'white' }) })
            )
          )
        )
      );
    }
  }]);

  return BasicTimelineExample;
}(React.Component);

export default BasicTimelineExample;

==> antd-mobile-2.1.8.tgz: package/es/steps/demo/basic.native.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
/* tslint:disable:jsx-no-multiline-js */
import { Icon, WingBlank } from 'antd-mobile';
import Steps from '../index.native';
var Step = Steps.Step;
import React from 'react';
import { ScrollView, Text, View } from 'react-native';

var BasicTimelineExample = function (_React$Component) {
  _inherits(BasicTimelineExample, _React$Component);

  function BasicTimelineExample(props) {
    _classCallCheck(this, BasicTimelineExample);

    var _this = _possibleConstructorReturn(this, (BasicTimelineExample.__proto__ || Object.getPrototypeOf(BasicTimelineExample)).call(this, props));

    _this.state = {
      steps1: [{ title: 'Finished', description: 'This is description' }, { title: 'In Progress', description: 'This is description' }, { title: 'Waiting', description: 'This is description' }],
      steps2: [{
        title: 'Finished',
        description: 'This is description',
        status: 'finish'
      }, {
        title: 'In Progress',
        description: 'This is description',
        status: 'process'
      }, {
        title: 'Waiting',
        description: 'This is description',
        status: 'error'
      }, {
        title: 'Waiting',
        description: 'This is description',
        status: 'wait'
      }]
    };
    return _this;
  }

  _createClass(BasicTimelineExample, [{
    key: 'render',
    value: function render() {
      return React.createElement(
        ScrollView,
        { style: { flex: 1 }, automaticallyAdjustContentInsets: false, showsHorizontalScrollIndicator: false, showsVerticalScrollIndicator: false },
        React.createElement(
          View,
          { style: { marginTop: 60 } },
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              { size: 'small', current: 1, direction: 'horizontal' },
              this.state.steps1.map(function (item, index) {
                return React.createElement(Step, { key: index, title: React.createElement(
                    View,
                    null,
                    React.createElement(
                      Text,
                      null,
                      'title:',
                      item.title
                    )
                  ), status: item.status });
              })
            )
          )
        ),
        React.createElement(
          View,
          { style: { marginTop: 60 } },
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              { size: 'small', current: 1 },
              this.state.steps1.map(function (item, index) {
                return React.createElement(Step, { key: index, title: React.createElement(
                    View,
                    null,
                    React.createElement(
                      Text,
                      null,
                      'title:',
                      item.title
                    )
                  ), description: React.createElement(
                    View,
                    null,
                    React.createElement(
                      Text,
                      null,
                      'desc:',
                      item.description
                    )
                  ), status: item.status });
              })
            )
          )
        ),
        React.createElement(
          View,
          null,
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              { size: 'small' },
              this.state.steps2.map(function (item, index) {
                return React.createElement(Step, { key: index, title: item.title, description: item.description, status: item.status });
              })
            )
          )
        ),
        React.createElement(
          View,
          null,
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              { current: 1 },
              this.state.steps1.map(function (item, index) {
                return React.createElement(Step, { key: index, title: item.title, description: item.description, status: item.status });
              })
            )
          )
        ),
        React.createElement(
          View,
          null,
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              null,
              this.state.steps2.map(function (item, index) {
                return React.createElement(Step, { key: index, title: item.title, description: item.description, status: item.status });
              })
            )
          )
        ),
        React.createElement(
          View,
          null,
          React.createElement(
            WingBlank,
            { size: 'lg' },
            React.createElement(
              Steps,
              { current: 1 },
              React.createElement(Step, { key: 0, title: 'Finished', description: 'This is description', status: 'finish' }),
              React.createElement(Step, { key: 1, title: 'Progress', description: 'This is description', status: 'progress' }),
              React.createElement(Step, { key: 2, title: 'Wait', description: 'This is description', status: 'wait', icon: React.createElement(Icon, { type: 'down', size: 20, color: 'white' }) })
            )
          )
        )
      );
    }
  }]);

  return BasicTimelineExample;
}(React.Component);

export default BasicTimelineExample;
